"use strict";
// ******************************************************************************************************
//  ValueList.tsx - Gbtc
//
//  Copyright © 2020, Grid Protection Alliance.  All Rights Reserved.
//
//  Licensed to the Grid Protection Alliance (GPA) under one or more contributor license agreements. See
//  the NOTICE file distributed with this work for additional information regarding copyright ownership.
//  The GPA licenses this file to you under the MIT License (MIT), the "License"; you may not use this
//  file except in compliance with the License. You may obtain a copy of the License at:
//
//      http://opensource.org/licenses/MIT
//
//  Unless agreed to in writing, the subject software distributed under the License is distributed on an
//  "AS-IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied. Refer to the
//  License for the specific language governing permissions and limitations.
//
//  Code Modification History:
//  ----------------------------------------------------------------------------------------------------
//  07/10/2021 - C. Lackner
//       Generated original version of source code.
// ******************************************************************************************************
var __assign = (this && this.__assign) || function () {
    __assign = Object.assign || function(t) {
        for (var s, i = 1, n = arguments.length; i < n; i++) {
            s = arguments[i];
            for (var p in s) if (Object.prototype.hasOwnProperty.call(s, p))
                t[p] = s[p];
        }
        return t;
    };
    return __assign.apply(this, arguments);
};
Object.defineProperty(exports, "__esModule", { value: true });
var React = require("react");
var react_table_1 = require("@gpa-gemstone/react-table");
var gpa_symbols_1 = require("@gpa-gemstone/gpa-symbols");
var react_interactive_1 = require("@gpa-gemstone/react-interactive");
var GroupForm_1 = require("./GroupForm");
var react_redux_1 = require("react-redux");
function ByValueListGroup(props) {
    var dispatch = (0, react_redux_1.useDispatch)();
    var data = (0, react_redux_1.useSelector)(props.ValueListSlice.SearchResults);
    var dataStatus = (0, react_redux_1.useSelector)(props.ValueListSlice.SearchStatus);
    var groups = (0, react_redux_1.useSelector)(props.ValueListSlice.Data);
    var groupStatus = (0, react_redux_1.useSelector)(props.ValueListSlice.Status);
    var _a = React.useState('Name'), sortKey = _a[0], setSortKey = _a[1];
    var _b = React.useState(false), asc = _b[0], setASC = _b[1];
    var emptyRecord = { ID: 0, Name: '', Description: '' };
    var _c = React.useState(false), showNew = _c[0], setShowNew = _c[1];
    var _d = React.useState(emptyRecord), record = _d[0], setRecord = _d[1];
    var items = (0, react_redux_1.useSelector)(props.ValueListItemSlice.Data);
    var itemStatus = (0, react_redux_1.useSelector)(props.ValueListItemSlice.Status);
    var _e = React.useState([]), search = _e[0], setSearch = _e[1];
    var _f = React.useState([]), newErrors = _f[0], setNewErrors = _f[1];
    var _g = React.useState(true), validName = _g[0], setValidName = _g[1];
    React.useEffect(function () {
        if (dataStatus === 'unintiated' || dataStatus === 'changed')
            dispatch(props.ValueListSlice.DBSearch({ filter: search, sortField: sortKey, ascending: asc }));
    }, [dispatch]);
    React.useEffect(function () {
        dispatch(props.ValueListSlice.DBSearch({ filter: search, sortField: sortKey, ascending: asc }));
    }, [search, asc, sortKey]);
    React.useEffect(function () {
        if (itemStatus === 'unintiated' || itemStatus === 'changed')
            dispatch(props.ValueListItemSlice.Fetch());
    }, [dispatch]);
    React.useEffect(function () {
        if (groupStatus === 'unintiated' || groupStatus === 'changed')
            dispatch(props.ValueListSlice.Fetch());
    }, [dispatch]);
    React.useEffect(function () {
        if (record.Name == null)
            setValidName(true);
        else
            setValidName(groups.findIndex(function (g) { return g.Name.toLowerCase() === record.Name.toLowerCase(); }) < 0);
    }, [record]);
    return (React.createElement("div", { style: { width: '100%', height: '100%' } },
        React.createElement(react_interactive_1.SearchBar, { CollumnList: [{ label: 'Name', key: 'Name', type: 'string', isPivotField: false }], SetFilter: function (flds) { return setSearch(flds); }, Direction: 'left', defaultCollumn: { label: 'Name', key: 'Name', type: 'string', isPivotField: false }, Width: '50%', Label: 'Search', ShowLoading: dataStatus === 'loading' || itemStatus === 'loading', ResultNote: dataStatus === 'error' || itemStatus === 'error' ? 'Could not complete Search' : 'Found ' + data.length + ' Groups', GetEnum: function () { return function () { }; } },
            React.createElement("li", { className: "nav-item", style: { width: '15%', paddingRight: 10 } },
                React.createElement("fieldset", { className: "border", style: { padding: '10px', height: '100%' } },
                    React.createElement("legend", { className: "w-auto", style: { fontSize: 'large' } }, "Actions:"),
                    React.createElement("form", null,
                        React.createElement("button", { className: "btn btn-primary", onClick: function (evt) { evt.preventDefault(); setRecord(__assign({}, emptyRecord)); setShowNew(true); } }, "Add Group"))))),
        React.createElement("div", { style: { width: '100%', height: 'calc( 100% - 136px)' } },
            React.createElement(react_table_1.default, { cols: [
                    { key: 'Name', field: 'Name', label: 'Name', headerStyle: { width: '15%' }, rowStyle: { width: '15%' } },
                    { key: 'Description', field: 'Description', label: 'Description/Comments', headerStyle: { width: 'auto' }, rowStyle: { width: 'auto' } },
                    { key: 'Items', field: 'Items', label: 'Items', headerStyle: { width: '10%' }, rowStyle: { width: '10%' }, content: function (item) { return items.filter(function (i) { return i.GroupID === item.ID; }).length; } },
                    { key: 'Scroll', label: '', headerStyle: { width: 17, padding: 0 }, rowStyle: { width: 0, padding: 0 } },
                ], tableClass: "table table-hover", data: data, sortKey: sortKey, ascending: asc, onSort: function (d) {
                    if (d.colKey === 'remove' || d.colKey === 'scroll' || d.colField === undefined)
                        return;
                    setSortKey(d.colField);
                    if (d.colField === sortKey)
                        setASC(function (b) { return !b; });
                    else
                        setASC(true);
                }, onClick: function (d) { return props.OnValueListSelect(d.row.ID); }, theadStyle: { fontSize: 'smaller', display: 'table', tableLayout: 'fixed', width: '100%' }, tbodyStyle: { display: 'block', overflowY: 'scroll', maxHeight: window.innerHeight - 300, width: '100%' }, rowStyle: { fontSize: 'smaller', display: 'table', tableLayout: 'fixed', width: '100%' }, selected: function (item) { return false; } })),
        React.createElement(react_interactive_1.Modal, { Show: showNew, Title: 'Add new Value List', ShowX: true, ShowCancel: false, DisableConfirm: newErrors.length > 0 || !validName, ConfirmShowToolTip: newErrors.length > 0 || !validName, ConfirmToolTipContent: React.createElement(React.Fragment, null,
                newErrors.map(function (t, i) { return React.createElement("p", { key: i },
                    " ",
                    gpa_symbols_1.CrossMark,
                    " ",
                    t); }),
                !validName ? React.createElement("p", null,
                    gpa_symbols_1.CrossMark,
                    " The Name has to be unique.") : null), CallBack: function (c) {
                setShowNew(false);
                if (c)
                    dispatch(props.ValueListSlice.DBAction({ verb: 'POST', record: record }));
            } },
            React.createElement(GroupForm_1.default, { Record: record, Setter: setRecord, ErrorSetter: setNewErrors }))));
}
exports.default = ByValueListGroup;
