"use strict";
// ******************************************************************************************************
//  Group.tsx - Gbtc
//
//  Copyright © 2020, Grid Protection Alliance.  All Rights Reserved.
//
//  Licensed to the Grid Protection Alliance (GPA) under one or more contributor license agreements. See
//  the NOTICE file distributed with this work for additional information regarding copyright ownership.
//  The GPA licenses this file to you under the MIT License (MIT), the "License"; you may not use this
//  file except in compliance with the License. You may obtain a copy of the License at:
//
//      http://opensource.org/licenses/MIT
//
//  Unless agreed to in writing, the subject software distributed under the License is distributed on an
//  "AS-IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied. Refer to the
//  License for the specific language governing permissions and limitations.
//
//  Code Modification History:
//  ----------------------------------------------------------------------------------------------------
//  07/04/2021 - C. Lackner
//       Generated original version of source code.
// ******************************************************************************************************
Object.defineProperty(exports, "__esModule", { value: true });
var React = require("react");
var react_interactive_1 = require("@gpa-gemstone/react-interactive");
var GroupInfo_1 = require("./GroupInfo");
var GroupItem_1 = require("./GroupItem");
var react_redux_1 = require("react-redux");
function ValueListGroup(props) {
    var dispatch = (0, react_redux_1.useDispatch)();
    var record = (0, react_redux_1.useSelector)(function (state) { return props.ValueListSlice.Data(state).find(function (i) { return i.ID === props.Id; }); });
    var recordStatus = (0, react_redux_1.useSelector)(props.ValueListSlice.Status);
    var _a = React.useState('items'), tab = _a[0], setTab = _a[1];
    var _b = React.useState(false), showWarning = _b[0], setShowWarning = _b[1];
    React.useEffect(function () {
        if (recordStatus === 'unintiated' || recordStatus === 'changed')
            dispatch(props.ValueListSlice.Fetch());
    }, [dispatch, recordStatus]);
    var Tabs = [
        { Id: "info", Label: "Value List Group Info" },
        { Id: "items", Label: "List Items" }
    ];
    if (recordStatus === 'error')
        return React.createElement("div", { style: { width: '100%', height: '100%' } },
            React.createElement(react_interactive_1.ServerErrorIcon, { Show: true, Label: 'A Server Error Occured. Please Reload the Application' }));
    if (record == null)
        return null;
    return (React.createElement("div", { style: { width: '100%', height: window.innerHeight - 63, maxHeight: window.innerHeight - 63, overflow: 'hidden', padding: 15 } },
        React.createElement("div", { className: "row" },
            React.createElement("div", { className: "col" },
                React.createElement("h2", null, record.Name)),
            React.createElement("div", { className: "col" },
                React.createElement("button", { className: "btn btn-danger pull-right", hidden: record == null, onClick: function () { return setShowWarning(true); } }, "Delete Value List Group (Permanent)"))),
        React.createElement("hr", null),
        React.createElement(react_interactive_1.TabSelector, { CurrentTab: tab, SetTab: function (t) { return setTab(t); }, Tabs: Tabs }),
        React.createElement("div", { className: "tab-content", style: { maxHeight: window.innerHeight - 235, overflow: 'hidden' } },
            React.createElement("div", { className: "tab-pane " + (tab === "info" ? " active" : "fade"), id: "info" },
                React.createElement(GroupInfo_1.default, { Record: record, Setter: function (r) {
                        dispatch(props.ValueListSlice.DBAction({ verb: 'PATCH', record: r }));
                    } })),
            React.createElement("div", { className: "tab-pane " + (tab === "items" ? " active" : "fade"), id: "items" },
                React.createElement(GroupItem_1.default, { Record: record, ValueListItemSlice: props.ValueListItemSlice }))),
        React.createElement(react_interactive_1.Warning, { Message: 'This will permanently remove the ValueList Group. Are you sure you want to continue?', Title: 'Warning', Show: showWarning, CallBack: function (c) {
                setShowWarning(false);
                if (c) {
                    dispatch(props.ValueListSlice.DBAction({ verb: 'DELETE', record: record }));
                    props.OnDelete();
                }
            } })));
}
exports.default = ValueListGroup;
