"use strict";
// ******************************************************************************************************
//  GroupInfo.tsx - Gbtc
//
//  Copyright © 2021, Grid Protection Alliance.  All Rights Reserved.
//
//  Licensed to the Grid Protection Alliance (GPA) under one or more contributor license agreements. See
//  the NOTICE file distributed with this work for additional information regarding copyright ownership.
//  The GPA licenses this file to you under the MIT License (MIT), the "License"; you may not use this
//  file except in compliance with the License. You may obtain a copy of the License at:
//
//      http://opensource.org/licenses/MIT
//
//  Unless agreed to in writing, the subject software distributed under the License is distributed on an
//  "AS-IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied. Refer to the
//  License for the specific language governing permissions and limitations.
//
//  Code Modification History:
//  ----------------------------------------------------------------------------------------------------
//  07/04/2021 - C. Lackner
//       Generated original version of source code.
// ******************************************************************************************************
Object.defineProperty(exports, "__esModule", { value: true });
var React = require("react");
var GroupForm_1 = require("./GroupForm");
var react_interactive_1 = require("@gpa-gemstone/react-interactive");
var gpa_symbols_1 = require("@gpa-gemstone/gpa-symbols");
var InfoWindow = function (props) {
    var _a = React.useState(props.Record), record = _a[0], setRecord = _a[1];
    var _b = React.useState([]), errors = _b[0], setErrors = _b[1];
    var _c = React.useState([]), warnings = _c[0], setWarnings = _c[1];
    var _d = React.useState('None'), hover = _d[0], setHover = _d[1];
    React.useEffect(function () {
        var w = [];
        if (record == null)
            return;
        if (record.Name !== props.Record.Name)
            w.push('Changes to Name will be lost.');
        if (record.Description !== props.Record.Description)
            w.push('Changes to Description will be lost.');
        setWarnings(w);
    }, [props.Record, record]);
    if (record == null)
        return null;
    return (React.createElement("div", { className: "card", style: { marginBottom: 10 } },
        React.createElement("div", { className: "card-header" },
            React.createElement("div", { className: "row" },
                React.createElement("div", { className: "col" },
                    React.createElement("h4", null, "Value List Group Information:")))),
        React.createElement("div", { className: "card-body" },
            React.createElement(GroupForm_1.default, { Record: record, Setter: function (r) { return setRecord(r); }, ErrorSetter: setErrors })),
        React.createElement("div", { className: "card-footer" },
            React.createElement("div", { className: "btn-group mr-2" },
                React.createElement("button", { className: "btn btn-primary" + (errors.length > 0 || warnings.length === 0 ? ' disabled' : ''), onClick: function () {
                        if (errors.length === 0 && warnings.length > 0)
                            props.Setter(record);
                    }, hidden: record.ID === 0, "data-tooltip": 'Update', onMouseEnter: function () { return setHover('Update'); }, onMouseLeave: function () { return setHover('None'); } }, "Update")),
            React.createElement(react_interactive_1.ToolTip, { Show: hover === 'Clear' && (errors.length > 0), Position: 'top', Theme: 'dark', Target: "Update" }, errors.map(function (t, i) { return React.createElement("p", { key: i },
                gpa_symbols_1.CrossMark,
                " ",
                t); })),
            React.createElement("div", { className: "btn-group mr-2" },
                React.createElement("button", { className: "btn btn-default", onClick: function () { return setRecord(props.Record); }, disabled: warnings.length === 0, "data-tooltip": 'Clr', onMouseEnter: function () { return setHover('Clear'); }, onMouseLeave: function () { return setHover('None'); } }, "Reset")),
            React.createElement(react_interactive_1.ToolTip, { Show: hover === 'Clear' && (warnings.length > 0), Position: 'top', Theme: 'dark', Target: "Clr" }, warnings.map(function (t, i) { return React.createElement("p", { key: i },
                gpa_symbols_1.Warning,
                " ",
                t); })))));
};
exports.default = InfoWindow;
