"use strict";
// ******************************************************************************************************
//  GroupItem.tsx - Gbtc
//
//  Copyright © 2021, Grid Protection Alliance.  All Rights Reserved.
//
//  Licensed to the Grid Protection Alliance (GPA) under one or more contributor license agreements. See
//  the NOTICE file distributed with this work for additional information regarding copyright ownership.
//  The GPA licenses this file to you under the MIT License (MIT), the "License"; you may not use this
//  file except in compliance with the License. You may obtain a copy of the License at:
//
//      http://opensource.org/licenses/MIT
//
//  Unless agreed to in writing, the subject software distributed under the License is distributed on an
//  "AS-IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied. Refer to the
//  License for the specific language governing permissions and limitations.
//
//  Code Modification History:
//  ----------------------------------------------------------------------------------------------------
//  07/04/2021 - C. Lackner
//       Generated original version of source code.
// ******************************************************************************************************
var __assign = (this && this.__assign) || function () {
    __assign = Object.assign || function(t) {
        for (var s, i = 1, n = arguments.length; i < n; i++) {
            s = arguments[i];
            for (var p in s) if (Object.prototype.hasOwnProperty.call(s, p))
                t[p] = s[p];
        }
        return t;
    };
    return __assign.apply(this, arguments);
};
Object.defineProperty(exports, "__esModule", { value: true });
var React = require("react");
var ItemForm_1 = require("./ItemForm");
var react_interactive_1 = require("@gpa-gemstone/react-interactive");
var react_table_1 = require("@gpa-gemstone/react-table");
var gpa_symbols_1 = require("@gpa-gemstone/gpa-symbols");
var react_redux_1 = require("react-redux");
function GroupItemsWindow(props) {
    var dispatch = (0, react_redux_1.useDispatch)();
    var recordStatus = (0, react_redux_1.useSelector)(props.ValueListItemSlice.Status);
    var data = (0, react_redux_1.useSelector)(props.ValueListItemSlice.Data);
    var parentID = (0, react_redux_1.useSelector)((props.ValueListItemSlice.ParentID === undefined ? function (state) { return -1; } : props.ValueListItemSlice.ParentID));
    var _a = React.useState('Value'), sortField = _a[0], setSortField = _a[1];
    var _b = React.useState(false), ascending = _b[0], setAscending = _b[1];
    var emptyRecord = { ID: 0, GroupID: props.Record.ID, Value: '', AltValue: '', SortOrder: 0 };
    var _c = React.useState(emptyRecord), record = _c[0], setRecord = _c[1];
    var _d = React.useState(false), showNew = _d[0], setShowNew = _d[1];
    var _e = React.useState([]), newErrors = _e[0], setNewErrors = _e[1];
    var _f = React.useState(true), validValue = _f[0], setValidValue = _f[1];
    React.useEffect(function () {
        if (recordStatus === 'unintiated' || recordStatus === 'changed' || parentID !== props.Record.ID)
            dispatch(props.ValueListItemSlice.Fetch(props.Record.ID));
    }, [recordStatus, dispatch]);
    React.useEffect(function () {
        dispatch(props.ValueListItemSlice.Sort({ Ascending: ascending, SortField: sortField }));
    }, [sortField, ascending]);
    React.useEffect(function () {
        if (record.Value === null)
            setValidValue(true);
        if (data.findIndex(function (d) { return d.Value.toLowerCase() === record.Value.toLowerCase(); }) > -1)
            setValidValue(false);
        else
            setValidValue(true);
    }, [record, data]);
    return (React.createElement("div", { className: "card", style: { marginBottom: 10 } },
        React.createElement("div", { className: "card-header" },
            React.createElement("div", { className: "row" },
                React.createElement("div", { className: "col" },
                    React.createElement("h4", null, "List Items:")))),
        React.createElement("div", { className: "card-body" },
            React.createElement("div", { className: "row" },
                React.createElement("div", { style: { width: '100%', height: window.innerHeight - 421, maxHeight: window.innerHeight - 421, padding: 0, overflowY: 'auto' } },
                    React.createElement(react_table_1.SearchableTable, { cols: [
                            { key: 'Value', field: 'Value', label: 'Value', headerStyle: { width: 'auto' }, rowStyle: { width: 'auto' } },
                            { key: 'AltValue', field: 'AltValue', label: 'Alternate Value', headerStyle: { width: 'auto' }, rowStyle: { width: 'auto' } },
                            { key: 'SortOrder', field: 'SortOrder', label: 'Sort Order', headerStyle: { width: 'auto' }, rowStyle: { width: 'auto' } },
                            { key: 'remove', label: '', headerStyle: { width: '10%' }, rowStyle: { width: '10%' }, content: function (item) { return React.createElement("button", { className: "btn btn-sm", onClick: function (e) {
                                        e.preventDefault();
                                        dispatch(props.ValueListItemSlice.DBAction({ verb: 'DELETE', record: item }));
                                    } },
                                    React.createElement("span", null,
                                        React.createElement("i", { className: "fa fa-times" }))); }
                            },
                            { key: 'scroll', label: '', headerStyle: { width: 17, padding: 0 }, rowStyle: { width: 0, padding: 0 } },
                        ], tableClass: "table table-hover", data: data, sortKey: sortField, onSort: function (d) {
                            if (d.colKey === 'remove' || d.colKey === 'scroll' || d.colField === undefined)
                                return;
                            setSortField(d.colField);
                            if (d.colField === sortField)
                                setAscending(function (asc) { return !asc; });
                            else
                                setAscending(true);
                        }, ascending: true, onClick: function () { }, theadStyle: { fontSize: 'smaller', display: 'table', tableLayout: 'fixed', width: '100%' }, tbodyStyle: { display: 'block', overflowY: 'scroll', maxHeight: window.innerHeight - 300, width: '100%' }, rowStyle: { fontSize: 'smaller', display: 'table', tableLayout: 'fixed', width: '100%' }, selected: function (item) { return false; }, matchSearch: function (item, search) { return item.Value.toLowerCase().indexOf(search.toLowerCase()) > -1; } })))),
        React.createElement("div", { className: "card-footer" },
            React.createElement("div", { className: "btn-group mr-2" },
                React.createElement("button", { className: "btn btn-primary pull-right", "data-toggle": "modal", "data-target": "#exampleModal", onClick: function () { setRecord(__assign(__assign({}, emptyRecord), { GroupID: props.Record.ID })); setShowNew(true); } }, "Add Item"))),
        React.createElement(react_interactive_1.Modal, { Title: 'Add new List Item', Show: showNew, Size: 'lg', ShowX: true, ShowCancel: false, DisableConfirm: newErrors.length > 0 || !validValue, ConfirmShowToolTip: newErrors.length > 0 || !validValue, ConfirmToolTipContent: React.createElement(React.Fragment, null,
                newErrors.map(function (t, i) { return React.createElement("p", { key: i },
                    " ",
                    gpa_symbols_1.CrossMark,
                    " ",
                    t); }),
                !validValue ? React.createElement("p", null,
                    " ",
                    gpa_symbols_1.CrossMark,
                    " A Value has to be unique in a given Item List.") : null), CallBack: function (c) {
                setShowNew(false);
                if (c)
                    dispatch(props.ValueListItemSlice.DBAction({ verb: 'POST', record: record }));
            } },
            React.createElement(ItemForm_1.default, { Record: record, Setter: setRecord, ErrorSetter: setNewErrors }))));
}
exports.default = GroupItemsWindow;
