"use strict";
// ******************************************************************************************************
//  ByUser.tsx - Gbtc
//
//  Copyright © 2020, Grid Protection Alliance.  All Rights Reserved.
//
//  Licensed to the Grid Protection Alliance (GPA) under one or more contributor license agreements. See
//  the NOTICE file distributed with this work for additional information regarding copyright ownership.
//  The GPA licenses this file to you under the MIT License (MIT), the "License"; you may not use this
//  file except in compliance with the License. You may obtain a copy of the License at:
//
//      http://opensource.org/licenses/MIT
//
//  Unless agreed to in writing, the subject software distributed under the License is distributed on an
//  "AS-IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied. Refer to the
//  License for the specific language governing permissions and limitations.
//
//  Code Modification History:
//  ----------------------------------------------------------------------------------------------------
//  07/14/2021 - C. Lackner
//       Generated original version of source code.
// ******************************************************************************************************
var __assign = (this && this.__assign) || function () {
    __assign = Object.assign || function(t) {
        for (var s, i = 1, n = arguments.length; i < n; i++) {
            s = arguments[i];
            for (var p in s) if (Object.prototype.hasOwnProperty.call(s, p))
                t[p] = s[p];
        }
        return t;
    };
    return __assign.apply(this, arguments);
};
Object.defineProperty(exports, "__esModule", { value: true });
var React = require("react");
var react_table_1 = require("@gpa-gemstone/react-table");
var gpa_symbols_1 = require("@gpa-gemstone/gpa-symbols");
var react_interactive_1 = require("@gpa-gemstone/react-interactive");
var CryptoJS = require("crypto-js");
var _ = require("lodash");
var UserForm_1 = require("./UserForm");
var react_redux_1 = require("react-redux");
var defaultSearchcols = [
    { label: 'First Name', key: 'FirstName', type: 'string', isPivotField: false },
    { label: 'Last Name', key: 'LastName', type: 'string', isPivotField: false },
    { label: 'Location', key: 'Location', type: 'string', isPivotField: false },
    { label: 'Phone', key: 'Phone', type: 'string', isPivotField: false },
    { label: 'Email', key: 'Email', type: 'string', isPivotField: false },
];
function ByUser(props) {
    var dispatch = (0, react_redux_1.useDispatch)();
    var search = (0, react_redux_1.useSelector)(props.UserSlice.SearchFilters);
    var data = (0, react_redux_1.useSelector)(props.UserSlice.SearchResults);
    var userStatus = (0, react_redux_1.useSelector)(props.UserSlice.Status);
    var searchStatus = (0, react_redux_1.useSelector)(props.UserSlice.SearchStatus);
    var sortField = (0, react_redux_1.useSelector)(props.UserSlice.SortField);
    var ascending = (0, react_redux_1.useSelector)(props.UserSlice.Ascending);
    var currentUserAccount = (0, react_redux_1.useSelector)(props.UserSlice.CurrentUser);
    var adlFields = (0, react_redux_1.useSelector)(props.AdditionalFieldSlice.Fields);
    var adlFieldStatus = (0, react_redux_1.useSelector)(props.AdditionalFieldSlice.FieldStatus);
    var _a = React.useState(defaultSearchcols), filterableList = _a[0], setFilterableList = _a[1];
    var _b = React.useState(false), showModal = _b[0], setShowModal = _b[1];
    var _c = React.useState([]), userError = _c[0], setUserError = _c[1];
    var valueListItems = (0, react_redux_1.useSelector)(props.ValueListItemSlice.Data);
    var valueListItemStatus = (0, react_redux_1.useSelector)(props.ValueListItemSlice.Status);
    var valueListGroups = (0, react_redux_1.useSelector)(props.ValueListGroupSlice.Data);
    var valueListGroupStatus = (0, react_redux_1.useSelector)(props.ValueListGroupSlice.Status);
    var _d = React.useState('unintiated'), pageStatus = _d[0], setPageStatus = _d[1];
    React.useEffect(function () {
        if (userStatus === 'error' || adlFieldStatus === 'error' || valueListItemStatus === 'error' || valueListGroupStatus === 'error')
            setPageStatus('error');
        else if (userStatus === 'loading' || adlFieldStatus === 'loading' || valueListItemStatus === 'loading' || valueListGroupStatus === 'loading')
            setPageStatus('loading');
        else
            setPageStatus('idle');
    }, [userStatus, adlFieldStatus, valueListItemStatus, valueListGroupStatus]);
    React.useEffect(function () {
        if (adlFieldStatus === 'unintiated' || adlFieldStatus === 'changed')
            dispatch(props.AdditionalFieldSlice.FetchField());
    }, [dispatch, adlFieldStatus]);
    React.useEffect(function () {
        dispatch(props.UserSlice.DBSearch({ sortField: sortField, ascending: ascending, filter: search }));
        dispatch(props.UserSlice.SetNewUser());
    }, [dispatch]);
    React.useEffect(function () {
        if (valueListItemStatus === 'unintiated' || valueListItemStatus === 'changed')
            dispatch(props.ValueListItemSlice.Fetch());
    }, [dispatch, valueListItemStatus]);
    React.useEffect(function () {
        if (valueListGroupStatus === 'unintiated' || valueListGroupStatus === 'changed')
            dispatch(props.ValueListGroupSlice.Fetch());
    }, [dispatch, valueListGroupStatus]);
    React.useEffect(function () {
        function ConvertType(type) {
            if (type === 'string' || type === 'integer' || type === 'number' || type === 'datetime' || type === 'boolean')
                return { type: type };
            return { type: 'enum', enum: [{ Label: type, Value: type }] };
        }
        var ordered = _.orderBy(defaultSearchcols.concat(adlFields.map(function (item) { return (__assign({ label: "[AF] " + item.FieldName, key: item.FieldName }, ConvertType(item.Type))); })), ['label'], ["asc"]);
        setFilterableList(ordered);
    }, [adlFields]);
    if (pageStatus === 'error')
        return React.createElement("div", { style: { width: '100%', height: '100%' } },
            React.createElement(react_interactive_1.ServerErrorIcon, { Show: true, Label: 'A Server Error Occured. Please Reload the Application' }));
    return (React.createElement("div", { style: { width: '100%', height: '100%' } },
        React.createElement(react_interactive_1.LoadingScreen, { Show: pageStatus === 'loading' }),
        React.createElement(react_interactive_1.SearchBar, { CollumnList: filterableList, SetFilter: function (flds) { return dispatch(props.UserSlice.DBSearch({ sortField: sortField, ascending: ascending, filter: flds })); }, Direction: 'left', defaultCollumn: { label: 'Last Name', key: 'LastName', type: 'string', isPivotField: false }, Width: '50%', Label: 'Search', ShowLoading: searchStatus === 'loading', ResultNote: searchStatus === 'error' ? 'Could not complete Search' : 'Found ' + data.length + ' UserAccounts', GetEnum: function (setOptions, field) {
                if (field.type !== 'enum' || field.enum === undefined || field.enum.length !== 1)
                    return function () { };
                var grpName = (field.enum !== undefined ? field.enum[0].Value.toLowerCase() : '');
                var grpIndex = valueListGroups.findIndex(function (g) { return g.Name.toLowerCase() === grpName; });
                if (grpIndex < 0)
                    return function () { };
                setOptions(valueListItems.filter(function (v) { return v.GroupID === valueListGroups[grpIndex].ID; }).map(function (item) { return ({ Value: item.ID.toString(), Label: item.Value }); }));
                return function () { };
            } },
            React.createElement("li", { className: "nav-item", style: { width: '15%', paddingRight: 10 } },
                React.createElement("fieldset", { className: "border", style: { padding: '10px', height: '100%' } },
                    React.createElement("legend", { className: "w-auto", style: { fontSize: 'large' } }, "Actions:"),
                    React.createElement("form", null,
                        React.createElement("button", { className: "btn btn-primary", onClick: function (event) { event.preventDefault(); setShowModal(true); } }, "Add User"))))),
        React.createElement("div", { style: { width: '100%', height: 'calc( 100% - 136px)' } },
            React.createElement(react_table_1.default, { cols: [
                    { key: 'Name', field: 'Name', label: 'User Name', headerStyle: { width: '10%' }, rowStyle: { width: '10%' } },
                    { key: 'FirstName', field: 'FirstName', label: 'First Name', headerStyle: { width: '10%' }, rowStyle: { width: '10%' } },
                    { key: 'LastName', field: 'LastName', label: 'Last Name', headerStyle: { width: '10%' }, rowStyle: { width: '10%' } },
                    { key: 'Phone', field: 'Phone', label: 'Phone', headerStyle: { width: '10%' }, rowStyle: { width: '10%' } },
                    { key: 'Email', field: 'Email', label: 'Email', headerStyle: { width: 'auto' }, rowStyle: { width: 'auto' } },
                    { key: 'scroll', label: '', headerStyle: { width: 17, padding: 0 }, rowStyle: { width: 0, padding: 0 } },
                ], tableClass: "table table-hover", data: data, sortKey: sortField, ascending: ascending, onSort: function (d) {
                    if (d.colField === undefined)
                        return;
                    if (d.colField !== sortField)
                        dispatch(props.UserSlice.DBSearch({ sortField: sortField, ascending: !ascending, filter: search }));
                    else
                        dispatch(props.UserSlice.DBSearch({ sortField: d.colField, ascending: true, filter: search }));
                }, onClick: function (d) { return props.OnUserSelect(d.row.ID); }, theadStyle: { fontSize: 'smaller', display: 'table', tableLayout: 'fixed', width: '100%' }, tbodyStyle: { display: 'block', overflowY: 'scroll', maxHeight: window.innerHeight - 300, width: '100%' }, rowStyle: { fontSize: 'smaller', display: 'table', tableLayout: 'fixed', width: '100%' }, selected: function (item) { return false; } })),
        React.createElement(react_interactive_1.Modal, { Show: showModal, Size: 'lg', ShowCancel: false, ShowX: true, ConfirmText: 'Save', Title: 'Add User', CallBack: function (confirm) {
                if (confirm)
                    dispatch(props.UserSlice.DBAction({ verb: 'POST', record: __assign(__assign({}, currentUserAccount), { Password: CryptoJS.SHA256(currentUserAccount.Password + "0").toString(CryptoJS.enc.Base64) }) }));
                dispatch(props.UserSlice.SetNewUser());
                setShowModal(false);
            }, ConfirmShowToolTip: userError.length > 0, ConfirmToolTipContent: userError.map(function (t, i) { return React.createElement("p", { key: i },
                gpa_symbols_1.CrossMark,
                " ",
                t); }), DisableConfirm: userError.length > 0 }, currentUserAccount !== undefined ? React.createElement(UserForm_1.default, { UserAccount: currentUserAccount, Setter: function (u) { return dispatch(props.UserSlice.SetCurrentUser(u)); }, Edit: false, SetErrors: setUserError, UserSlice: props.UserSlice }) : null)));
}
exports.default = ByUser;
