"use strict";
// ******************************************************************************************************
//  User.tsx - Gbtc
//
//  Copyright © 2020, Grid Protection Alliance.  All Rights Reserved.
//
//  Licensed to the Grid Protection Alliance (GPA) under one or more contributor license agreements. See
//  the NOTICE file distributed with this work for additional information regarding copyright ownership.
//  The GPA licenses this file to you under the MIT License (MIT), the "License"; you may not use this
//  file except in compliance with the License. You may obtain a copy of the License at:
//
//      http://opensource.org/licenses/MIT
//
//  Unless agreed to in writing, the subject software distributed under the License is distributed on an
//  "AS-IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied. Refer to the
//  License for the specific language governing permissions and limitations.
//
//  Code Modification History:
//  ----------------------------------------------------------------------------------------------------
//  07/14/2021 - C. Lackner
//       Generated original version of source code.
// ******************************************************************************************************
Object.defineProperty(exports, "__esModule", { value: true });
var React = require("react");
var react_interactive_1 = require("@gpa-gemstone/react-interactive");
var UserInfo_1 = require("./UserInfo");
var UserPermissions_1 = require("./UserPermissions");
var AdditionalField_1 = require("./AdditionalField");
var react_redux_1 = require("react-redux");
var react_forms_1 = require("@gpa-gemstone/react-forms");
function User(props) {
    var dispatch = (0, react_redux_1.useDispatch)();
    var user = (0, react_redux_1.useSelector)(props.UserSlice.CurrentUser);
    var status = (0, react_redux_1.useSelector)(props.UserSlice.Status);
    var _a = React.useState('userInfo'), tab = _a[0], setTab = _a[1];
    var _b = React.useState(false), showWarning = _b[0], setShowWarning = _b[1];
    React.useEffect(function () {
        dispatch(props.UserSlice.LoadExistingUser(props.UserID));
    }, [dispatch, props.UserID]);
    if (status === 'error')
        return React.createElement("div", { style: { width: '100%', height: '100%' } },
            React.createElement(react_interactive_1.ServerErrorIcon, { Show: true, Label: 'A Server Error Occured. Please Reload the Application' }));
    var Tabs = [
        { Id: "userInfo", Label: "User Info" },
        { Id: "permissions", Label: "Permissions" },
        { Id: "additionalFields", Label: "Additional Fields" }
    ];
    return (React.createElement("div", { style: { width: '100%', height: window.innerHeight - 63, maxHeight: window.innerHeight - 63, overflow: 'hidden', padding: 15 } },
        React.createElement("div", { className: "row" },
            React.createElement("div", { className: "col" },
                React.createElement("h2", null, user != null ? user.FirstName + " " + user.LastName : '')),
            React.createElement("div", { className: "col" },
                React.createElement("button", { className: "btn btn-danger pull-right", hidden: user == null, onClick: function () { return setShowWarning(true); } }, "Delete User"))),
        React.createElement(react_interactive_1.LoadingScreen, { Show: status === 'loading' }),
        React.createElement("hr", null),
        React.createElement(react_interactive_1.TabSelector, { CurrentTab: tab, SetTab: function (t) { return setTab(t); }, Tabs: Tabs }),
        React.createElement("div", { className: "tab-content", style: { maxHeight: window.innerHeight - 235, overflow: 'hidden' } },
            React.createElement("div", { className: "tab-pane " + (tab === "userInfo" ? " active" : "fade") },
                React.createElement(UserInfo_1.default, { UserSlice: props.UserSlice })),
            React.createElement("div", { className: "tab-pane " + (tab === "permissions" ? " active" : "fade") }, user == null ? null : React.createElement(UserPermissions_1.default, { UserID: user.ID, RoleSlice: props.SecurityRoleSlice })),
            React.createElement("div", { className: "tab-pane " + (tab === "additionalFields" ? " active" : "fade"), style: { maxHeight: window.innerHeight - 215 } },
                React.createElement(AdditionalField_1.default, { Id: props.UserID, AdditionalFieldSlice: props.AdditionalFieldSlice, ValueListItemSlice: props.ValueListItemSlice, ValueListGroupSlice: props.ValueListGroupSlice, EmptyField: { ID: -1, IsSecure: false, FieldName: '', Type: 'string' }, GetFieldValueIndex: function (field, values) { return values.findIndex(function (v) { return v.AdditionalUserFieldID === field.ID; }); }, GetFieldIndex: function (value, fields) { return fields.findIndex(function (f) { return f.ID === value.AdditionalUserFieldID; }); }, FieldKeySelector: function (field) { return (field.ID === -1 ? 'new' : field.ID.toString()); }, ValidateField: function () { return []; }, FieldUI: function (fld, setter) { return React.createElement(react_forms_1.CheckBox, { Record: fld, Field: 'IsSecure', Label: "Secure Data", Setter: setter }); }, CreateValue: function (fld) { return ({ Value: '', ID: -1, UserAccountID: props.UserID, AdditionalUserFieldID: fld.ID }); } }))),
        React.createElement(react_interactive_1.Warning, { Message: 'This will permanently remove the User. Are you sure you want to continue?', Title: 'Warning', Show: showWarning, CallBack: function (c) {
                setShowWarning(false);
                if (c) {
                    dispatch(props.UserSlice.DBAction({ verb: 'DELETE', record: user }));
                    props.OnDelete();
                }
            } })));
}
exports.default = User;
