"use strict";
// ******************************************************************************************************
//  UserForm.tsx - Gbtc
//
//  Copyright © 2020, Grid Protection Alliance.  All Rights Reserved.
//
//  Licensed to the Grid Protection Alliance (GPA) under one or more contributor license agreements. See
//  the NOTICE file distributed with this work for additional information regarding copyright ownership.
//  The GPA licenses this file to you under the MIT License (MIT), the "License"; you may not use this
//  file except in compliance with the License. You may obtain a copy of the License at:
//
//      http://opensource.org/licenses/MIT
//
//  Unless agreed to in writing, the subject software distributed under the License is distributed on an
//  "AS-IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied. Refer to the
//  License for the specific language governing permissions and limitations.
//
//  Code Modification History:
//  ----------------------------------------------------------------------------------------------------
//  07/14/2021 - C. Lackner
//       Generated original version of source code.
// ******************************************************************************************************
Object.defineProperty(exports, "__esModule", { value: true });
var React = require("react");
var react_forms_1 = require("@gpa-gemstone/react-forms");
var _ = require("lodash");
var react_redux_1 = require("react-redux");
function UserForm(props) {
    var dispatch = (0, react_redux_1.useDispatch)();
    var _a = React.useState(false), updatedAD = _a[0], setUpdatedAD = _a[1];
    var userValidation = (0, react_redux_1.useSelector)(props.UserSlice.ADValidation);
    var _b = React.useState([]), userError = _b[0], setUserError = _b[1];
    React.useEffect(function () {
        if (userValidation === 'Valid' && !props.Edit && updatedAD === false)
            dispatch(props.UserSlice.ADUpdate());
    }, [userValidation, updatedAD]);
    React.useEffect(function () {
        if (props.SetErrors !== undefined)
            props.SetErrors(userError);
    }, [userError, props.SetErrors]);
    React.useEffect(function () {
        if (props.UserAccount == null)
            return;
        var e = [];
        if (props.UserAccount.Name == null || props.UserAccount.Name.length === 0)
            e.push('An AccountName is required.');
        if (props.UserAccount.UseADAuthentication && userValidation !== 'Valid')
            e.push('The user could not be validated by the AD.');
        setUserError(e);
    }, [props.UserAccount, userValidation]);
    function validUserAccountField(user, field) {
        if (field === 'Name')
            return user.Name != null && user.Name.length > 0 && user.Name.length <= 200;
        else if (field === 'Password')
            return user.Password == null || user.Password.length <= 200;
        else if (field === 'FirstName')
            return user.FirstName == null || user.FirstName.length <= 200;
        else if (field === 'LastName')
            return user.LastName == null || user.LastName.length <= 200;
        else if (field === 'Phone')
            return user.Phone == null || user.Phone.length <= 200;
        else if (field === 'Email')
            return user.Email == null || user.Email.length <= 200;
        else if (field === "ChangePasswordOn")
            return user.ChangePasswordOn == null;
        return false;
    }
    if (props.UserAccount == null)
        return null;
    return (React.createElement(React.Fragment, null,
        React.createElement("form", null,
            React.createElement("div", { className: "row" },
                React.createElement("div", { className: "col" },
                    React.createElement(react_forms_1.Input, { Record: props.UserAccount, Disabled: props.Edit, Field: 'Name', Feedback: 'A Name of less than 200 characters is required.', Valid: function (field) { return validUserAccountField(props.UserAccount, field); }, Setter: function (record) {
                            setUpdatedAD(false);
                            props.Setter(record);
                        } }),
                    React.createElement("div", { className: "row", style: { position: 'absolute', top: 0, left: 100 }, hidden: !props.UserAccount.UseADAuthentication },
                        React.createElement("span", { id: "resolvingAccount", hidden: userValidation !== 'Resolving' },
                            React.createElement("i", { style: { height: 10, width: 10, color: 'grey' }, className: "fa fa fa-spin fa-refresh" }),
                            "\u00A0",
                            React.createElement("em", { className: "small" }, "Resolving account details...")),
                        React.createElement("span", { id: "accountValid", hidden: userValidation !== 'Valid' },
                            React.createElement("i", { style: { height: 20, width: 20, color: 'green' }, className: "fa fa-check-circle" }),
                            "\u00A0",
                            React.createElement("em", { className: "small" }, "Resolved account name ")),
                        React.createElement("span", { id: "accountInvalid", hidden: userValidation !== 'Invalid' },
                            React.createElement("i", { style: { height: 20, width: 20, color: 'red' }, className: "fa fa-times-circle" }),
                            "\u00A0",
                            React.createElement("em", { className: "small" }, "Cannot resolve account name")),
                        React.createElement("span", { id: "accountUnknown", hidden: userValidation !== 'Unknown' },
                            React.createElement("i", { style: { height: 20, width: 20, color: 'orange' }, className: "fa fa-exclamation-circle" }),
                            "\u00A0",
                            React.createElement("em", { className: "small" }, "Valid account name is not a user or Active Directory access is limited"))),
                    React.createElement("button", { style: { marginBottom: 10 }, type: "button", className: "btn btn-primary btn-sm", onClick: function (evt) { evt.preventDefault(); dispatch(props.UserSlice.ADUpdate()); }, hidden: userValidation !== 'Valid' || !props.Edit }, "Load Information from AD"),
                    React.createElement("div", { className: "card" },
                        React.createElement("div", { className: "card-header" },
                            React.createElement("div", { className: "row" },
                                React.createElement("div", { className: "col-xs-4" },
                                    React.createElement("div", { className: "form-check-inline" },
                                        React.createElement("label", { className: "form-check-label" },
                                            React.createElement("input", { disabled: props.Edit, className: 'form-check-input', type: 'radio', checked: props.UserAccount.UseADAuthentication, onChange: function (e) {
                                                    var record = _.clone(props.UserAccount);
                                                    record.UseADAuthentication = e.target.checked;
                                                    props.Setter(record);
                                                } }),
                                            "Active Directory User"))),
                                React.createElement("div", { className: "col-xs-4" },
                                    React.createElement("div", { className: "form-check-inline" },
                                        React.createElement("label", { className: "form-check-label" },
                                            React.createElement("input", { disabled: props.Edit, className: 'form-check-input', type: 'radio', checked: !props.UserAccount.UseADAuthentication, onChange: function (e) {
                                                    var record = _.clone(props.UserAccount);
                                                    record.UseADAuthentication = !e.target.checked;
                                                    props.Setter(record);
                                                } }),
                                            "Database User"))))),
                        React.createElement("div", { className: "card-body", hidden: !props.UserAccount.UseADAuthentication },
                            React.createElement("div", { className: "row" },
                                React.createElement("div", { className: "col" },
                                    React.createElement(react_forms_1.Input, { Record: props.UserAccount, Field: 'FirstName', Label: 'First Name', Feedback: 'First Name must be less than 200 characters.', Valid: function (field) { return validUserAccountField(props.UserAccount, field); }, Setter: props.Setter }),
                                    React.createElement(react_forms_1.Input, { Record: props.UserAccount, Field: 'LastName', Label: 'Last Name', Feedback: 'Last Name must be less than 200 characters.', Valid: function (field) { return validUserAccountField(props.UserAccount, field); }, Setter: props.Setter })),
                                React.createElement("div", { className: "col" },
                                    React.createElement(react_forms_1.Input, { Record: props.UserAccount, Field: 'Phone', Feedback: 'Phone must be less than 200 characters.', Valid: function (field) { return validUserAccountField(props.UserAccount, field); }, Setter: props.Setter }),
                                    React.createElement(react_forms_1.Input, { Record: props.UserAccount, Field: 'Email', Feedback: 'Email must be less than 200 characters.', Valid: function (field) { return validUserAccountField(props.UserAccount, field); }, Setter: props.Setter })))),
                        React.createElement("div", { className: "card-body", hidden: props.UserAccount.UseADAuthentication },
                            React.createElement("div", { className: "row" },
                                React.createElement("div", { className: "col" },
                                    React.createElement(react_forms_1.Input, { Record: props.UserAccount, Field: 'Password', Feedback: 'Password must be less than 200 characters.', Type: 'password', Valid: function (field) { return validUserAccountField(props.UserAccount, field); }, Setter: props.Setter }),
                                    React.createElement(react_forms_1.Input, { Record: props.UserAccount, Field: 'FirstName', Label: 'First Name', Feedback: 'First Name must be less than 200 characters.', Valid: function (field) { return validUserAccountField(props.UserAccount, field); }, Setter: props.Setter }),
                                    React.createElement(react_forms_1.Input, { Record: props.UserAccount, Field: 'LastName', Label: 'Last Name', Feedback: 'Last Name must be less than 200 characters.', Valid: function (field) { return validUserAccountField(props.UserAccount, field); }, Setter: props.Setter })),
                                React.createElement("div", { className: "col" },
                                    React.createElement(react_forms_1.Input, { Record: props.UserAccount, Field: 'Phone', Feedback: 'Password must be less than 200 characters.', Valid: function (field) { return validUserAccountField(props.UserAccount, field); }, Setter: props.Setter }),
                                    React.createElement(react_forms_1.Input, { Record: props.UserAccount, Field: 'Email', Feedback: 'Password must be less than 200 characters.', Valid: function (field) { return validUserAccountField(props.UserAccount, field); }, Setter: props.Setter }),
                                    React.createElement(react_forms_1.DatePicker, { Record: props.UserAccount, Field: 'ChangePasswordOn', Label: 'Change Password On', Setter: props.Setter, Valid: function (field) { return validUserAccountField(props.UserAccount, field); } })))),
                        React.createElement("div", { className: "row" },
                            React.createElement("div", { className: "col", style: { margin: 10 } },
                                React.createElement(react_forms_1.CheckBox, { Record: props.UserAccount, Label: 'Locked Out', Field: 'LockedOut', Setter: props.Setter }),
                                React.createElement(react_forms_1.CheckBox, { Record: props.UserAccount, Field: 'Approved', Setter: props.Setter })),
                            React.createElement("div", { className: "col-lg-6" },
                                React.createElement(react_forms_1.CheckBox, { Record: props.UserAccount, Label: 'Phone Confirmed', Field: 'PhoneConfirmed', Setter: props.Setter }),
                                React.createElement(react_forms_1.CheckBox, { Record: props.UserAccount, Label: 'Email Confirmed', Field: 'EmailConfirmed', Setter: props.Setter })))))))));
}
exports.default = UserForm;
