"use strict";
// ******************************************************************************************************
//  UserInfo.tsx - Gbtc
//
//  Copyright © 2020, Grid Protection Alliance.  All Rights Reserved.
//
//  Licensed to the Grid Protection Alliance (GPA) under one or more contributor license agreements. See
//  the NOTICE file distributed with this work for additional information regarding copyright ownership.
//  The GPA licenses this file to you under the MIT License (MIT), the "License"; you may not use this
//  file except in compliance with the License. You may obtain a copy of the License at:
//
//      http://opensource.org/licenses/MIT
//
//  Unless agreed to in writing, the subject software distributed under the License is distributed on an
//  "AS-IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied. Refer to the
//  License for the specific language governing permissions and limitations.
//
//  Code Modification History:
//  ----------------------------------------------------------------------------------------------------
//  07/14/2021 - C. Lackner
//       Generated original version of source code.
// ******************************************************************************************************
var __assign = (this && this.__assign) || function () {
    __assign = Object.assign || function(t) {
        for (var s, i = 1, n = arguments.length; i < n; i++) {
            s = arguments[i];
            for (var p in s) if (Object.prototype.hasOwnProperty.call(s, p))
                t[p] = s[p];
        }
        return t;
    };
    return __assign.apply(this, arguments);
};
Object.defineProperty(exports, "__esModule", { value: true });
var React = require("react");
var CryptoJS = require("crypto-js");
var UserForm_1 = require("./UserForm");
var react_interactive_1 = require("@gpa-gemstone/react-interactive");
var gpa_symbols_1 = require("@gpa-gemstone/gpa-symbols");
var react_redux_1 = require("react-redux");
function UserInfo(props) {
    var dispatch = (0, react_redux_1.useDispatch)();
    var currentUser = (0, react_redux_1.useSelector)(props.UserSlice.CurrentUser);
    var _a = React.useState(currentUser), user = _a[0], setUser = _a[1];
    var _b = React.useState([]), warnings = _b[0], setWarning = _b[1];
    var _c = React.useState('None'), hover = _c[0], setHover = _c[1];
    React.useEffect(function () {
        if (currentUser == null || user == null)
            return;
        var encryptedPwd = (user.Password !== currentUser.Password ? CryptoJS.SHA256(user.Password + "0").toString(CryptoJS.enc.Base64) : user.Password);
        var w = [];
        if (currentUser.FirstName !== user.FirstName)
            w.push('Changes to First Name will be lost.');
        if (currentUser.LastName !== user.LastName)
            w.push('Changes to Last Name will be lost.');
        if (currentUser.Phone !== user.Phone)
            w.push('Changes to Phone will be lost.');
        if (currentUser.Email !== user.Email)
            w.push('Changes to Email will be lost.');
        if (currentUser.ChangePasswordOn !== user.ChangePasswordOn)
            w.push('Changes to Change Password Date will be lost.');
        if (currentUser.LockedOut !== user.LockedOut)
            w.push('Changes to Account Locked Status will be lost.');
        if (currentUser.Approved !== user.Approved)
            w.push('Changes Account Approved Status will be lost.');
        if (currentUser.PhoneConfirmed !== user.PhoneConfirmed)
            w.push('Changes to Phone Confirmed Status will be lost.');
        if (currentUser.EmailConfirmed !== user.EmailConfirmed)
            w.push('Changes to Email confirmed Status will be lost.');
        if (!currentUser.UseADAuthentication && currentUser.Password !== encryptedPwd)
            w.push('Changes to Password will be lost.');
        setWarning(w);
    }, [currentUser, user]);
    React.useEffect(function () { setUser(currentUser); }, [currentUser]);
    function updateUser() {
        var encryptedPwd = (user.Password !== currentUser.Password ? CryptoJS.SHA256(user.Password + "0").toString(CryptoJS.enc.Base64) : user.Password);
        dispatch(props.UserSlice.SetCurrentUser(__assign(__assign({}, user), { Name: currentUser.Name, Password: encryptedPwd })));
        dispatch(props.UserSlice.DBAction({ verb: 'PATCH', record: __assign(__assign({}, user), { Name: currentUser.Name, Password: encryptedPwd }) }));
    }
    return (React.createElement("div", { className: "card", style: { marginBottom: 10 } },
        React.createElement("div", { className: "card-header" },
            React.createElement("div", { className: "row" },
                React.createElement("div", { className: "col" },
                    React.createElement("h4", null, "User Information:")))),
        React.createElement("div", { className: "card-body", style: { height: window.innerHeight - 440, maxHeight: window.innerHeight - 440, overflowY: 'auto' } },
            React.createElement(UserForm_1.default, { UserAccount: user, Setter: function (u) { return setUser(u); }, Edit: true, UserSlice: props.UserSlice })),
        React.createElement("div", { className: "card-footer" },
            React.createElement("div", { className: "btn-group mr-2" },
                React.createElement("button", { className: "btn btn-primary", onClick: function () { return updateUser(); }, disabled: warnings.length === 0 }, "Update")),
            React.createElement("div", { className: "btn-group mr-2" },
                React.createElement("button", { className: "btn btn-default", onClick: function () { return setUser(currentUser); }, disabled: warnings.length === 0, "data-tooltip": 'Clr', onMouseEnter: function () { return setHover('Clear'); }, onMouseLeave: function () { return setHover('None'); } }, "Reset")),
            React.createElement(react_interactive_1.ToolTip, { Show: hover === 'Clear' && (warnings.length > 0), Position: 'top', Theme: 'dark', Target: "Clr" }, warnings.map(function (t, i) { return React.createElement("p", { key: i },
                gpa_symbols_1.Warning,
                " ",
                t); })))));
}
exports.default = UserInfo;
