"use strict";
// ******************************************************************************************************
//  UserPermission.tsx - Gbtc
//
//  Copyright © 2020, Grid Protection Alliance.  All Rights Reserved.
//
//  Licensed to the Grid Protection Alliance (GPA) under one or more contributor license agreements. See
//  the NOTICE file distributed with this work for additional information regarding copyright ownership.
//  The GPA licenses this file to you under the MIT License (MIT), the "License"; you may not use this
//  file except in compliance with the License. You may obtain a copy of the License at:
//
//      http://opensource.org/licenses/MIT
//
//  Unless agreed to in writing, the subject software distributed under the License is distributed on an
//  "AS-IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied. Refer to the
//  License for the specific language governing permissions and limitations.
//
//  Code Modification History:
//  ----------------------------------------------------------------------------------------------------
//  07/14/2021 - C. Lackner
//       Generated original version of source code.
// ******************************************************************************************************
Object.defineProperty(exports, "__esModule", { value: true });
var React = require("react");
var _ = require("lodash");
var react_forms_1 = require("@gpa-gemstone/react-forms");
var react_redux_1 = require("react-redux");
function UserPermission(props) {
    var dispatch = (0, react_redux_1.useDispatch)();
    var currentRoles = (0, react_redux_1.useSelector)(props.RoleSlice.Roles);
    var allRoleStatus = (0, react_redux_1.useSelector)(props.RoleSlice.Status);
    var availableRoles = (0, react_redux_1.useSelector)(props.RoleSlice.AvailableRoles);
    var currentRoleStatus = (0, react_redux_1.useSelector)(props.RoleSlice.CurrentRoleStatus);
    var _a = React.useState([]), workingRoles = _a[0], setWorkingRoles = _a[1];
    var _b = React.useState(false), changed = _b[0], setChanged = _b[1];
    React.useEffect(function () {
        if (allRoleStatus === 'unintiated' || allRoleStatus === 'changed')
            dispatch(props.RoleSlice.FetchRoles());
    }, [dispatch, allRoleStatus]);
    React.useEffect(function () {
        if (currentRoleStatus === 'unintiated' || currentRoleStatus === 'changed')
            dispatch(props.RoleSlice.FetchUserRoles(props.UserID));
    }, [dispatch, currentRoleStatus, props.UserID]);
    React.useEffect(function () {
        resetCurrentRoles(availableRoles, currentRoles);
    }, [currentRoles, availableRoles]);
    function resetCurrentRoles(avRoles, currRoles) {
        setChanged(false);
        setWorkingRoles(avRoles.map(function (src) {
            var upd = _.cloneDeep(src);
            upd.Assigned = currRoles.find(function (usrc) { return usrc.ApplicationRoleID === upd.ID; }) !== undefined;
            return upd;
        }));
    }
    return (React.createElement("div", { className: "card", style: { marginBottom: 10 } },
        React.createElement("div", { className: "card-header" },
            React.createElement("div", { className: "row" },
                React.createElement("div", { className: "col" },
                    React.createElement("h4", null, "User Permissions:")))),
        React.createElement("div", { className: "card-body" },
            React.createElement("div", { className: "row" },
                React.createElement("div", { className: "col" },
                    React.createElement("fieldset", { className: "border", style: { padding: '10px', height: '100%' } },
                        React.createElement("legend", { className: "w-auto", style: { fontSize: 'large' } }, "System Center:"),
                        React.createElement("form", null, workingRoles.map(function (scr, i, array) { return React.createElement(react_forms_1.CheckBox, { key: scr.ID, Record: scr, Field: 'Assigned', Label: scr.Name, Setter: function (record) {
                                scr.Assigned = record.Assigned;
                                var newArray = _.clone(array);
                                setWorkingRoles(newArray);
                                setChanged(true);
                            } }); })))),
                React.createElement("div", { className: "col" }))),
        React.createElement("div", { className: "card-footer" },
            React.createElement("div", { className: "btn-group mr-2" },
                React.createElement("button", { className: "btn btn-primary", onClick: function () {
                        return dispatch(props.RoleSlice.SetUserRoles({
                            UserId: props.UserID,
                            Roles: workingRoles.filter(function (scr) { return scr.Assigned; }).map(function (scr) { return ({ ID: '00000000-0000-0000-0000-000000000000', ApplicationRoleID: scr.ID, UserAccountID: props.UserID }); })
                        }));
                    }, disabled: !changed }, "Update")),
            React.createElement("div", { className: "btn-group mr-2" },
                React.createElement("button", { className: "btn btn-default", onClick: function () { return resetCurrentRoles(availableRoles, currentRoles); }, disabled: !changed }, "Reset")))));
}
exports.default = UserPermission;
